Crate verbs

Crate verbs 

Embeddable Heddle facade scaffolding.

Re-exports

pub use actor::ActorChainEntry;
pub use actor::ActorDoneOptions;
pub use actor::ActorDonePlan;
pub use actor::ActorEntryReport;
pub use actor::ActorListReport;
pub use actor::ActorShowReport;
pub use actor::assemble_actor_entry;
pub use actor::complete_actor_entry;
pub use actor::filter_actors;
pub use actor::filter_actors_ref;
pub use actor::list_actors;
pub use actor::list_actors_from_registry;
pub use actor::mark_actor_done;
pub use actor::plan_actor_done;
pub use actor::show_actor_by_session;
pub use actor::show_actor_from_entry;
pub use agent_fanout::FanoutBaseFacts;
pub use agent_fanout::FanoutBaseSelection;
pub use agent_fanout::FanoutCommandSpec;
pub use agent_fanout::FanoutLaneAvailability;
pub use agent_fanout::FanoutLanePreflightBlock;
pub use agent_fanout::FanoutLaneReport;
pub use agent_fanout::FanoutNodeSpec;
pub use agent_fanout::FanoutPlan;
pub use agent_fanout::FanoutPlanError;
pub use agent_fanout::FanoutPlanReport;
pub use agent_fanout::FanoutPlanRequest;
pub use agent_fanout::FanoutTaskPlaceholder;
pub use agent_fanout::assemble_fanout_plan_report;
pub use agent_fanout::assemble_fanout_start_commands;
pub use agent_fanout::check_fanout_start_preflight;
pub use agent_fanout::ensure_unique_thread_names;
pub use agent_fanout::fanout_child_body;
pub use agent_fanout::fanout_parent_body;
pub use agent_fanout::fanout_parent_delegated_by;
pub use agent_fanout::fanout_start_attach_rule;
pub use agent_fanout::parse_fanout_lane;
pub use agent_fanout::parse_fanout_lanes;
pub use agent_fanout::plan_fanout;
pub use agent_fanout::select_fanout_base;
pub use agent_fanout::select_fanout_parent_thread;
pub use agent_ops::AgentCaptureOptions;
pub use agent_ops::AgentCapturePlan;
pub use agent_ops::AgentCapturePlanError;
pub use agent_ops::AgentCaptureThreadCheck;
pub use agent_ops::AgentExplainReport;
pub use agent_ops::AgentReadyOptions;
pub use agent_ops::AgentReadyPlan;
pub use agent_ops::AgentReadyPlanError;
pub use agent_ops::AgentReservationListReport;
pub use agent_ops::AgentReservationReport;
pub use agent_ops::assemble_agent_explain;
pub use agent_ops::assemble_agent_reservation;
pub use agent_ops::assemble_agent_reservation_list;
pub use agent_ops::check_agent_capture_thread;
pub use agent_ops::default_attach_reason_message;
pub use agent_ops::filter_agent_reservations;
pub use agent_ops::filter_agent_reservations_ref;
pub use agent_ops::plan_agent_capture;
pub use agent_ops::plan_agent_ready;
pub use approval_plan::EligibilitySummary;
pub use approval_plan::approval_recorded_message;
pub use approval_plan::approval_revoked_message;
pub use approval_plan::approvals_empty_message;
pub use approval_plan::approvals_header;
pub use approval_plan::eligibility_allowed_message;
pub use approval_plan::eligibility_approvals_counted_message;
pub use approval_plan::eligibility_blocked_message;
pub use approval_plan::format_unix_secs_display;
pub use approval_plan::format_unix_secs_label;
pub use approval_plan::plan_eligibility_summary;
pub use approval_plan::short_state_id;
pub use approval_plan::state_id_bytes_to_string;
pub use approval_plan::timestamp_secs_u64;
pub use approval_plan::unmet_requirement_line;
pub use clone_plan::AdoptPlan;
pub use clone_plan::AdoptPlanError;
pub use clone_plan::AdoptPlanOptions;
pub use clone_plan::CloneMode;
pub use clone_plan::ClonePlan;
pub use clone_plan::ClonePlanError;
pub use clone_plan::ClonePlanFacts;
pub use clone_plan::ClonePlanOptions;
pub use clone_plan::CloneRemoteSource;
pub use clone_plan::CloneSecurityPreflight;
pub use clone_plan::CloneThreadSelectError;
pub use clone_plan::MonorepoCloneJsonReport;
pub use clone_plan::MonorepoClonePlan;
pub use clone_plan::MonorepoClonePlanError;
pub use clone_plan::MonorepoCloneResultSummary;
pub use clone_plan::MonorepoEdgeFacts;
pub use clone_plan::MonorepoEdgeSkipReason;
pub use clone_plan::MonorepoExecutionPlan;
pub use clone_plan::MonorepoExecutionProgress;
pub use clone_plan::MonorepoNodeExecution;
pub use clone_plan::MonorepoNodeExecutionError;
pub use clone_plan::MonorepoNodeExecutionStep;
pub use clone_plan::MonorepoNodeFacts;
pub use clone_plan::MonorepoNodePlan;
pub use clone_plan::MonorepoNodeStepOptions;
pub use clone_plan::MonorepoPlacedJsonRow;
pub use clone_plan::MonorepoPlacedNodeSummary;
pub use clone_plan::MonorepoSkippedChild;
pub use clone_plan::MonorepoSkippedJsonRow;
pub use clone_plan::UnsupportedCloneFlag;
pub use clone_plan::absolute_path;
pub use clone_plan::assemble_clone_security_preflight;
pub use clone_plan::assemble_monorepo_clone_json_report;
pub use clone_plan::assemble_monorepo_clone_result_summary;
pub use clone_plan::looks_like_git_overlay_url;
pub use clone_plan::looks_like_local_path;
pub use clone_plan::monorepo_execution_progress;
pub use clone_plan::monorepo_rel_display;
pub use clone_plan::normalize_clone_depth;
pub use clone_plan::plan_adopt;
pub use clone_plan::plan_clone;
pub use clone_plan::plan_monorepo_clone;
pub use clone_plan::plan_monorepo_execution;
pub use clone_plan::plan_monorepo_node_steps;
pub use clone_plan::resolve_adopt_start_path;
pub use clone_plan::resolve_clone_destination;
pub use clone_plan::select_clone_checkout_thread;
pub use clone_plan::select_clone_mode;
pub use clone_plan::validate_clone_destination;
pub use clone_plan::validate_clone_mode_options;
pub use clone_plan::validate_monorepo_clone_options;
pub use clone_plan::validate_monorepo_execution;
pub use clone_plan::validate_monorepo_node_execution;
pub use collapse_plan::CollapsePlan;
pub use collapse_plan::collapse_has_source_states;
pub use collapse_plan::collapse_states_required_kind;
pub use collapse_plan::plan_collapse;
pub use context::ExecutionContext;
pub use context::ExecutionContextBuilder;
pub use context::Verbosity;
pub use context_plan::ContextContentPlanError;
pub use context_plan::ContextRmPlanError;
pub use context_plan::annotation_passes_filters;
pub use context_plan::annotation_status_label;
pub use context_plan::audit_duplicate_count;
pub use context_plan::audit_staleness_key;
pub use context_plan::audit_target_key;
pub use context_plan::context_target_kind_and_label;
pub use context_plan::count_active_annotations;
pub use context_plan::filter_annotations;
pub use context_plan::next_annotation_tags;
pub use context_plan::plan_annotation_content_source;
pub use context_plan::plan_context_rm;
pub use context_plan::suggestion_tier_human_label;
pub use context_plan::suggestion_tier_token;
pub use context_plan::supersede_reuses_original_scope;
pub use context_plan::supersede_reuses_original_target;
pub use contract::HeddleReport;
pub use contract::MachineOutputKind;
pub use contract::OutputDiscriminator;
pub use contract::ReportContract;
pub use contract::schema_for_report;
pub use diff::ContextSnippet;
pub use diff::DiffOptions;
pub use diff::DiffReport;
pub use diff::DiffStats;
pub use diff::FileChange;
pub use diff::FileContextEntry;
pub use diff::FileEolState;
pub use diff::LineCounts;
pub use diff::LineDiff;
pub use diff::PlainGitDiffProbe;
pub use diff::SemanticChangeEntry;
pub use diff::SymlinkChange;
pub use diff::attach_show_context;
pub use diff::change_line_counts;
pub use diff::compute_state_diff;
pub use diff::compute_tree_diff;
pub use diff::diff;
pub use diff::diff_worktree_status;
pub use diff::plain_git_head_diff;
pub use diff::render_diff_patch;
pub use diff::render_diff_patch_bytes;
pub use diff::should_render_modified_pair;
pub use diff::trim_added_decorations_for_display;
pub use diff::worktree_context_state;
pub use diff::write_diff_patch;
pub use fsck::FsckError;
pub use fsck::FsckOptions;
pub use fsck::FsckRepair;
pub use fsck::FsckReport;
pub use fsck::fsck;
pub use gc_plan::GcDryRunPlan;
pub use gc_plan::gc_consolidated_mirror_message;
pub use gc_plan::gc_dry_run_messages;
pub use gc_plan::gc_dry_run_pack_message;
pub use gc_plan::gc_dry_run_prune_message;
pub use gc_plan::gc_pack_message;
pub use gc_plan::gc_pinned_redactions_message;
pub use gc_plan::gc_preserved_redactions_message;
pub use gc_plan::gc_prune_loose_message;
pub use gc_plan::gc_pruned_git_mapping_message;
pub use gc_plan::gc_status_token;
pub use gc_plan::plan_gc_dry_run;
pub use harness_json::VerificationClaimPolicyFacts;
pub use harness_json::VerificationClaimTrustFacts;
pub use harness_json::first_value_string;
pub use harness_json::map_from_pairs;
pub use harness_json::merge_string_vec;
pub use harness_json::opencode_tool_name;
pub use harness_json::opencode_tool_status;
pub use harness_json::parse_relay_payload;
pub use harness_json::raw_git_preservation_command;
pub use harness_json::repository_verification_allows_success_claim;
pub use harness_json::value_array_join;
pub use harness_json::value_cost_micros;
pub use harness_json::value_cost_micros_u64;
pub use harness_json::value_string;
pub use harness_json::value_string_array;
pub use harness_json::value_u64;
pub use harness_json::value_u64_string;
pub use harness_policy::ExplicitAgentBind;
pub use harness_policy::HarnessFingerprint;
pub use harness_policy::HarnessKind;
pub use harness_policy::HarnessProbeDecision;
pub use harness_policy::SegmentRotation;
pub use harness_policy::SessionAttachDecision;
pub use harness_policy::SessionAttachFacts;
pub use harness_policy::SessionAttachRule;
pub use harness_policy::SessionLookupFact;
pub use harness_policy::SessionPolicy;
pub use harness_policy::TokenSidFact;
pub use harness_policy::WorktreeSessionFact;
pub use harness_policy::attach_published_segment_fields;
pub use harness_policy::cursor_segment_rotation;
pub use harness_policy::decide_harness_probe;
pub use harness_policy::decide_session_attach;
pub use harness_policy::detect_harness_kind;
pub use harness_policy::fingerprint_harness_from_hints;
pub use harness_policy::segment_rotation_policy;
pub use harness_policy::should_rotate_segment;
pub use hook_plan::HookInstallSourceKind;
pub use hook_plan::HookInstallSourcePlan;
pub use hook_plan::hook_install_empty_stdin_kind;
pub use hook_plan::hook_install_source_required_kind;
pub use hook_plan::hook_unknown_kind;
pub use hook_plan::plan_hook_install_source;
pub use identity_cursor::IDENTITY_CURSOR_FILE;
pub use identity_cursor::IdentityCursor;
pub use identity_cursor::expire_identity_cursor;
pub use identity_cursor::harness_kind_from_basename;
pub use identity_cursor::identity_cursor_path;
pub use identity_cursor::published_field;
pub use identity_cursor::read_identity_cursor;
pub use identity_cursor::stamp_identity_cursor;
pub use identity_cursor::thought_level_from_payload;
pub use identity_cursor::value_string_or_named;
pub use identity_cursor::write_identity_cursor;
pub use identity_payload::claude_cursor_patch;
pub use identity_payload::codex_cursor_patch;
pub use identity_payload::cursor_event_expires;
pub use identity_payload::cursor_patch_from_child_env;
pub use identity_payload::cursor_patch_from_stdin;
pub use identity_payload::opencode_cursor_patch;
pub use identity_payload::opencode_event_type;
pub use identity_payload::pi_cursor_patch;
pub use identity_payload::stamp_event_expires;
pub use identity_payload::stamp_harness_name;
pub use init_plan::InitPrincipalPlan;
pub use init_plan::SET_PRINCIPAL_COMMAND;
pub use init_plan::init_side_effects;
pub use init_plan::principal_is_unconfigured;
pub use init_plan::resolve_absolute_path;
pub use init_plan::select_init_principal;
pub use log_plan::ReflogLine;
pub use log_plan::extract_scope_bytes;
pub use log_plan::fit_author;
pub use log_plan::format_missing_blobs_suffix;
pub use log_plan::parse_reflog_line;
pub use log_plan::session_list_status;
pub use log_plan::short_oid;
pub use log_plan::summarize_context_line;
pub use log_plan::summarize_paths;
pub use log_plan::timeline_branch_reason;
pub use log_plan::timeline_cursor_reason;
pub use log_plan::timeline_label;
pub use log_plan::timeline_recovery_status;
pub use log_plan::timeline_tool_status;
pub use log_plan::truncate_with_ellipsis;
pub use log_plan::yes_no;
pub use marker_plan::MarkerDeleteSelector;
pub use marker_plan::MarkerDeleteSelectorError;
pub use marker_plan::marker_bulk_delete_message;
pub use marker_plan::marker_create_message;
pub use marker_plan::marker_delete_message;
pub use marker_plan::marker_list_filter_matches;
pub use marker_plan::marker_prefix_is_valid;
pub use marker_plan::plan_marker_delete_selector;
pub use merge::GitCommitInfo;
pub use merge::GitCommitPreview;
pub use merge::MergeAttemptPlan;
pub use merge::MergeOptions;
pub use merge::MergePlan;
pub use merge::MergeRelation;
pub use merge::MergeRelationKind;
pub use merge::MergeReport;
pub use merge::OperatorAction as MergeOperatorAction;
pub use merge::OperatorCommandOutput as MergeOperatorCommandOutput;
pub use merge::PreviewTarget;
pub use merge::ThreadPreviewReport;
pub use merge::ThreeWayMergeOutcome;
pub use merge::apply_merged_tree;
pub use merge::apply_merged_tree_external;
pub use merge::bench_detect_renames;
pub use merge::bench_find_merge_base;
pub use merge::bench_three_way_merge;
pub use merge::build_thread_preview_report;
pub use merge::ensure_worktree_clean;
pub use merge::merge_thread;
pub use merge::merge_thread_into_current;
pub use merge::merge_thread_into_current_transactional;
pub use merge::merge_thread_into_current_with_machine_contract;
pub use merge::prepare_dir_for_file_replacement;
pub use merge::try_three_way_merge_between_tips;
pub use onboarding::OnboardingAction;
pub use onboarding::OnboardingFacts;
pub use onboarding::OnboardingMode;
pub use onboarding::OnboardingPlan;
pub use onboarding::OnboardingRepositoryState;
pub use onboarding::plan_repository_onboarding;
pub use oplog_plan::OPLOG_RECOVER_DEFAULT_STRATEGY;
pub use oplog_plan::OplogRecoverFacts;
pub use oplog_plan::OplogRecoverStatus;
pub use oplog_plan::oplog_recover_damaged_bytes;
pub use oplog_plan::oplog_recover_damaged_range_display;
pub use oplog_plan::oplog_recover_detail_fields;
pub use oplog_plan::oplog_recover_entries_lost_display;
pub use oplog_plan::oplog_recover_headline;
pub use oplog_plan::oplog_recover_headline_from_facts;
pub use oplog_plan::oplog_recover_shows_detail;
pub use oplog_plan::oplog_recover_shows_strategy_field;
pub use oplog_plan::plan_oplog_recover;
pub use oplog_plan::plan_oplog_recover_status;
pub use principal::ResolvedPrincipal;
pub use principal::principal_source_display;
pub use principal::resolve_principal;
pub use principal::resolve_principal_without_repo;
pub use prove_plan::HostRepoPlanError;
pub use prove_plan::ProofStatusKind;
pub use prove_plan::proof_status_label;
pub use prove_plan::proof_submit_followup;
pub use prove_plan::require_host_repo;
pub use provenance_verify::ProvenanceReport;
pub use provenance_verify::StateProvenanceVerification;
pub use provenance_verify::verify_repository_provenance;
pub use purge_plan::PurgeApplyPlan;
pub use purge_plan::plan_purge_apply;
pub use purge_plan::purge_apply_message;
pub use purge_plan::purge_force_command;
pub use query::QueryHit;
pub use query::QueryReport;
pub use query::QueryRequest;
pub use query::query;
pub use rebase_plan::RebaseContinuePlan;
pub use rebase_plan::RebaseStartFacts;
pub use rebase_plan::RebaseStartPlan;
pub use rebase_plan::no_rebase_in_progress_kind;
pub use rebase_plan::plan_rebase_abort;
pub use rebase_plan::plan_rebase_continue;
pub use rebase_plan::plan_rebase_start;
pub use rebase_plan::rebase_target_not_found_kind;
pub use rebase_plan::rebase_target_required_kind;
pub use redact_plan::RedactionSignatureStatus;
pub use redact_plan::redaction_signature_status;
pub use redact_plan::short_public_key;
pub use remote::ALL_THREADS_MIRROR_COVERS_NOTE;
pub use remote::COMMITS_SEEN_SCOPE;
pub use remote::FORCE_DISCARD_WARNING;
pub use remote::GIT_NOTES_REF;
pub use remote::GIT_NOTES_VISIBILITY_WARNING;
pub use remote::GitConfigContext;
pub use remote::GitOverlayPushTracking;
pub use remote::GitRemoteConfigured;
pub use remote::GitUpstreamConfigured;
pub use remote::HostedPullResult;
pub use remote::HostedPullResultFields;
pub use remote::HostedPushPlan;
pub use remote::HostedPushResult;
pub use remote::HostedPushResultFields;
pub use remote::IncludedGitRemoteConfigError;
pub use remote::LocalTransferSummary;
pub use remote::MultiRefPushProgress;
pub use remote::PullExecutionFacts;
pub use remote::PullFailure;
pub use remote::PullOutcome;
pub use remote::PullOutcomeText;
pub use remote::PullPlan;
pub use remote::PullPlanRequest;
pub use remote::PushExecutionFacts;
pub use remote::PushFailure;
pub use remote::PushOutcome;
pub use remote::PushOutcomeText;
pub use remote::PushPath;
pub use remote::PushPlan;
pub use remote::PushPlanRequest;
pub use remote::RemoteInfo;
pub use remote::RemoteListReport;
pub use remote::RemotePreflightBlocker;
pub use remote::UNKNOWN_TRANSPORT_ERROR;
pub use remote::all_threads_mirror_coverage_note;
pub use remote::all_threads_uses_single_mirror_push;
pub use remote::build_pull_outcome;
pub use remote::build_push_outcome;
pub use remote::default_pull_thread_name;
pub use remote::default_push_thread_name;
pub use remote::first_multi_thread_push_failure;
pub use remote::format_connected_to;
pub use remote::format_mirror_failure_text;
pub use remote::format_mirror_success_text;
pub use remote::format_multi_ref_push_progress;
pub use remote::format_multi_thread_refs_detail;
pub use remote::format_pull_outcome_text;
pub use remote::format_pulling_from;
pub use remote::format_push_outcome_text;
pub use remote::format_pushing_to;
pub use remote::format_ref_list;
pub use remote::format_remote_state_detail;
pub use remote::git_overlay_current_thread_push_ok;
pub use remote::git_overlay_pull_execution_facts;
pub use remote::git_overlay_push_execution_facts;
pub use remote::git_overlay_push_scope_description;
pub use remote::git_overlay_ref_scope;
pub use remote::git_overlay_thread_mismatch_blocker;
pub use remote::heddle_pull_execution_facts;
pub use remote::heddle_pull_execution_facts_from_hosted;
pub use remote::heddle_pull_execution_facts_from_local;
pub use remote::heddle_single_push_execution_facts;
pub use remote::heddle_single_push_execution_facts_from_hosted;
pub use remote::heddle_single_push_execution_facts_from_local;
pub use remote::hosted_path_contains_internal_user_namespace;
pub use remote::hosted_spool_display_path;
pub use remote::is_native_transport_mismatch;
pub use remote::list_plain_git_remotes;
pub use remote::list_remotes;
pub use remote::local_pull_changed;
pub use remote::looks_like_git_forge_remote;
pub use remote::looks_like_git_remote_url;
pub use remote::looks_like_known_git_host;
pub use remote::looks_like_remote_location;
pub use remote::merged_remote_items;
pub use remote::message_indicates_already_exists;
pub use remote::multi_ref_progress_from_hosted_thread;
pub use remote::multi_ref_push_begin;
pub use remote::multi_ref_thread_failed;
pub use remote::multi_ref_thread_succeeded_hosted;
pub use remote::multi_ref_thread_succeeded_local;
pub use remote::multi_thread_failed_names;
pub use remote::multi_thread_push_execution_facts;
pub use remote::multi_thread_reported_refs;
pub use remote::named_thread_tip_mismatch_failure;
pub use remote::parse_hosted_pull_result;
pub use remote::parse_hosted_push_result;
pub use remote::plain_git_remote_items;
pub use remote::plan_hosted_push;
pub use remote::plan_pull;
pub use remote::plan_push;
pub use remote::pull_requires_clean_worktree;
pub use remote::pull_should_materialize;
pub use remote::pull_status;
pub use remote::pull_tip_changed;
pub use remote::pull_will_materialize;
pub use remote::push_scope_label;
pub use remote::push_status;
pub use remote::redact_internal_hosted_paths;
pub use remote::refuse_named_thread_tip_overwrite;
pub use remote::remote_advice_kind;
pub use remote::remote_missing_blocker;
pub use remote::remote_pull_failure;
pub use remote::remote_push_failure;
pub use remote::remote_urls_match;
pub use remote::resolve_default_push_remote_name;
pub use remote::resolve_default_remote_name;
pub use remote::resolved_default_remote_name;
pub use remote::show_plain_git_remote;
pub use remote::show_remote;
pub use remote::summarize_pull_outcome;
pub use remote::summarize_push_outcome;
pub use remote::transport_error_message;
pub use remote::transport_mismatch_blocker;
pub use remote::uses_git_overlay_mirror_rpc;
pub use remote::uses_local_git_overlay_transport;
pub use resolve::AgentReport;
pub use resolve::ConflictRangeReport;
pub use resolve::ConflictRegionReport;
pub use resolve::ConflictResolutionModeReport;
pub use resolve::ConflictResolutionReport;
pub use resolve::ConflictSideReport;
pub use resolve::PrincipalReport;
pub use resolve::ResolveReport;
pub use resolve::ResolverAttributionReport;
pub use resolve::ResolverKindReport;
pub use resolve_plan::ResolveSideSelection;
pub use resolve_plan::contains_line_start_conflict_markers;
pub use resolve_plan::path_is_active_conflict;
pub use resolve_plan::plan_resolve_side;
pub use resolve_plan::resolve_requires_marker_check;
pub use resolve_plan::unresolved_conflict_paths;
pub use revert_plan::RevertMessageMode;
pub use revert_plan::RevertOutcome;
pub use revert_plan::RevertPlan;
pub use revert_plan::RevertSuccessFacts;
pub use revert_plan::default_revert_commit_message;
pub use revert_plan::no_changes_to_revert_kind;
pub use revert_plan::no_changes_to_revert_summary;
pub use revert_plan::plan_revert;
pub use revert_plan::revert_has_no_changes;
pub use revert_plan::revert_inspect_command;
pub use revert_plan::revert_success_message;
pub use save::CaptureAgentReport;
pub use save::CaptureAttribution;
pub use save::CaptureDiagnostics;
pub use save::CaptureOptions;
pub use save::CapturePrincipalReport;
pub use save::CaptureProfile;
pub use save::CaptureReport;
pub use save::CommitGitIndexPlan;
pub use save::GitScope;
pub use save::SavePlan;
pub use save::SaveReport;
pub use save::SaveVerb;
pub use save::capture;
pub use save::commit_next_action_from_trust;
pub use save::commit_scope_text;
pub use save::complete_current_thread_manual_resolution;
pub use save::execute_save;
pub use save::plan_commit_git_index;
pub use save::plan_commit_git_index_only;
pub use save::plan_creates_new_state;
pub use save::plan_git_scope;
pub use save::plan_writes_git_checkpoint;
pub use save::recover_published_git_checkpoint;
pub use save::split_git_extra_paths;
pub use save::staged_commit_summary;
pub use save::tree_leaf_name;
pub use semantic_plan::HOT_EVENT_KIND_TOKENS;
pub use semantic_plan::HotEventKindToken;
pub use semantic_plan::hot_event_kind_label;
pub use semantic_plan::human_event_kind;
pub use semantic_plan::parse_hot_event_kind_token;
pub use status::ActorInfo;
pub use status::ChangesInfo;
pub use status::CoordinationStatus;
pub use status::FastShortStatusProfile;
pub use status::FastShortStatusReport;
pub use status::GitImportGuidanceReport;
pub use status::GitIndexPlan;
pub use status::MaterializedThreadInfo;
pub use status::ParallelThreadInfo;
pub use status::PlainGitStatusReport;
pub use status::RepositoryVerificationCheck;
pub use status::RepositoryVerificationHealth;
pub use status::StateInfo;
pub use status::StatusCombinedVerdict;
pub use status::StatusDetail;
pub use status::StatusOptions;
pub use status::StatusProfile;
pub use status::StatusReport;
pub use status::StatusThreadSummary;
pub use status::assess_materialized_threads;
pub use status::build_repository_verification_health_with_worktree_status;
pub use status::changes_from_worktree_status;
pub use status::changes_path_count;
pub use status::changes_paths;
pub use status::combined_verdict_axes;
pub use status::coordination_axis_clean;
pub use status::coordination_label;
pub use status::coordination_severity;
pub use status::fast_short_status_report;
pub use status::git_index_plan_for_root;
pub use status::health_severity;
pub use status::human_thread_health;
pub use status::large_capture_requires_force;
pub use status::plain_git_status_report;
pub use status::principal_is_default_unknown;
pub use status::principal_lacks_accountable_identity;
pub use status::resolve_coordination_with_trust;
pub use status::status;
pub use status::status_combined_verdict;
pub use thread::AvailableGitRef;
pub use thread::ThreadActorInfo;
pub use thread::ThreadListEntry;
pub use thread::ThreadListOptions;
pub use thread::ThreadListReport;
pub use thread::ThreadSummary;
pub use thread::ThreadTaskSummary;
pub use thread::ThreadUpdateBefore;
pub use thread::capture_thread_update_before;
pub use thread::collect_thread_summaries;
pub use thread::find_thread_summary;
pub use thread::list_threads;
pub use thread::list_threads_with_worktree_status;
pub use thread::save_thread_update;
pub use thread::split_available_git_refs;
pub use thread::thread_is_available_git_ref;
pub use thread::thread_is_imported_git_ref;
pub use thread::visibility_label;
pub use thread_lifecycle::CleanWorktreeGuard;
pub use thread_lifecycle::ThreadDropDisposition;
pub use thread_lifecycle::ThreadDropOptions;
pub use thread_lifecycle::ThreadDropPlan;
pub use thread_lifecycle::ThreadPromoteOptions;
pub use thread_lifecycle::ThreadPromotePlan;
pub use thread_lifecycle::ThreadRefreshOptions;
pub use thread_lifecycle::ThreadRefreshPlan;
pub use thread_lifecycle::contains_conflict_marker_bytes;
pub use thread_lifecycle::format_refresh_conflict_markers;
pub use thread_lifecycle::plan_clean_worktree_guard;
pub use thread_lifecycle::plan_cleanup_thread_drop;
pub use thread_lifecycle::plan_thread_drop;
pub use thread_lifecycle::plan_thread_promote;
pub use thread_lifecycle::plan_thread_refresh;
pub use thread_lifecycle::promote_confirm_in_place_removal;
pub use thread_lifecycle::promote_existing_checkout_path;
pub use thread_lifecycle::promote_in_place_conversion_candidate;
pub use thread_lifecycle::resolve_promote_target_path;
pub use thread_lifecycle::should_materialize_refresh_conflict_markers;
pub use thread_lifecycle::thread_mode_requires_unmount;
pub use thread_materialize::ADVISORY_ACTIVE_HEAVY_THREAD_THRESHOLD;
pub use thread_materialize::CheckoutCopyPolicy;
pub use thread_materialize::CheckoutPathPlan;
pub use thread_materialize::CheckoutRewindPlan;
pub use thread_materialize::CreateDirAttempt;
pub use thread_materialize::MaterializeStep;
pub use thread_materialize::RelativePathNormalizeError;
pub use thread_materialize::SelfCreatedDirRewindPlan;
pub use thread_materialize::SharedTargetRedirectDecision;
pub use thread_materialize::StartCleanupStep;
pub use thread_materialize::StartEffectKind;
pub use thread_materialize::StartEffectPreconditionError;
pub use thread_materialize::StartEffectStagingFacts;
pub use thread_materialize::StartTransactionPlan;
pub use thread_materialize::TargetDirClaimKind;
pub use thread_materialize::TargetDirCreateIntent;
pub use thread_materialize::TargetLeafRefusal;
pub use thread_materialize::TargetLeafShape;
pub use thread_materialize::ThreadMaterializePlan;
pub use thread_materialize::ThreadsRootPathClass;
pub use thread_materialize::ThreadsRootPathSafetyError;
pub use thread_materialize::append_safe_relative_components;
pub use thread_materialize::claim_kind_after_empty_dir_adoption;
pub use thread_materialize::claim_kind_for_create_attempt;
pub use thread_materialize::classify_materialize_error;
pub use thread_materialize::classify_path_vs_threads_root;
pub use thread_materialize::classify_target_leaf_shape;
pub use thread_materialize::effect_requires_established_claim;
pub use thread_materialize::mode_is_bytes_on_disk;
pub use thread_materialize::path_components_are_safe;
pub use thread_materialize::path_is_nested_in_reserved_region;
pub use thread_materialize::path_is_strict_descendant;
pub use thread_materialize::path_is_under_or_equal;
pub use thread_materialize::plan_checkout_copy_policy;
pub use thread_materialize::plan_checkout_path;
pub use thread_materialize::plan_checkout_rewind;
pub use thread_materialize::plan_hydrate;
pub use thread_materialize::plan_materialize_steps;
pub use thread_materialize::plan_self_created_dir_rewind;
pub use thread_materialize::plan_shared_target_redirect;
pub use thread_materialize::plan_start_cleanup;
pub use thread_materialize::plan_start_transaction;
pub use thread_materialize::plan_target_dir_create_intent;
pub use thread_materialize::plan_thread_materialize;
pub use thread_materialize::plan_write_manifest;
pub use thread_materialize::require_established_claim;
pub use thread_materialize::shared_target_redirect_applies;
pub use thread_materialize::shared_target_workspace_is_busy;
pub use thread_materialize::should_advise_shared_target;
pub use thread_materialize::threads_root_path_layout_allowed;
pub use thread_materialize::validate_empty_dir_adoption;
pub use thread_materialize::validate_start_effect_preconditions;
pub use thread_materialize::validate_threads_root_path_safety;
pub use thread_plan::AutoWorkspaceDefault;
pub use thread_plan::ExplicitPathPlacement;
pub use thread_plan::ThreadBaseError;
pub use thread_plan::ThreadBaseSelection;
pub use thread_plan::ThreadCreateOptions;
pub use thread_plan::ThreadCreatePlan;
pub use thread_plan::ThreadPathIsolationError;
pub use thread_plan::ThreadPlanError;
pub use thread_plan::ThreadStartOptions;
pub use thread_plan::ThreadStartPlan;
pub use thread_plan::WorkspaceModeRequest;
pub use thread_plan::active_reservation_blocks_start;
pub use thread_plan::active_reservation_path_matches;
pub use thread_plan::check_explicit_path_isolation;
pub use thread_plan::classify_explicit_path_placement;
pub use thread_plan::explicit_path_allowed_for_git_overlay;
pub use thread_plan::mode_honors_explicit_path;
pub use thread_plan::path_isolation_enforced;
pub use thread_plan::plan_thread_create;
pub use thread_plan::plan_thread_mode;
pub use thread_plan::plan_thread_start;
pub use thread_plan::select_thread_base;
pub use thread_plan::start_requires_clean_worktree;
pub use thread_plan::validate_thread_name;
pub use thread_shaping::CaptureSplitOptions;
pub use thread_shaping::NoPathsMatchedDetails;
pub use thread_shaping::ThreadMoveOptions;
pub use thread_shaping::ThreadMoveOutput;
pub use thread_shaping::ThreadShapingError;
pub use thread_shaping::capture_split;
pub use thread_shaping::thread_move;
pub use timeline_plan::TimelinePlanError;
pub use timeline_plan::TimelineSelection;
pub use timeline_plan::TimelineTargetOptions;
pub use timeline_plan::parse_branch_reason;
pub use timeline_plan::parse_materialize_mode;
pub use timeline_plan::parse_tool_status;
pub use timeline_plan::plan_timeline_target;
pub use timeline_plan::timeline_materialization_recovery_status;
pub use timeline_plan::timeline_materialize_status;
pub use undo::LiveThreadWorktree;
pub use undo::PurgeOpRef;
pub use undo::RedactOpRef;
pub use undo::RedactionUndoBatchFacts;
pub use undo::RequiredStateRef;
pub use undo::ThreadWorktreeHazard;
pub use undo::UndoApplyPlan;
pub use undo::UndoApplyPreflightError;
pub use undo::UndoApplyStep;
pub use undo::UndoBatchSummary;
pub use undo::UndoHistoryAction;
pub use undo::UndoListReport;
pub use undo::UndoOperationSummary;
pub use undo::UndoPlan;
pub use undo::UnsupportedRedoOp;
pub use undo::batch_status;
pub use undo::check_redaction_redo_supported;
pub use undo::check_redaction_undo_safe;
pub use undo::check_states_reachable;
pub use undo::check_thread_worktree_undo_safe;
pub use undo::collect_redaction_undo_facts;
pub use undo::collect_redo_required_states;
pub use undo::collect_thread_worktree_hazards;
pub use undo::collect_undo_required_states;
pub use undo::collect_unsupported_redo_ops;
pub use undo::empty_history_refusal;
pub use undo::human_operation_description;
pub use undo::human_post_undo_trust_status;
pub use undo::human_undo_redo_message;
pub use undo::list_undo_history;
pub use undo::list_undo_history_ctx;
pub use undo::live_materialized_path_blocks_undo;
pub use undo::machine_undo_redo_message;
pub use undo::plan_redo_apply_steps;
pub use undo::plan_redo_batches;
pub use undo::plan_undo_apply;
pub use undo::plan_undo_apply_steps;
pub use undo::plan_undo_batches;
pub use undo::require_nonempty_history;
pub use undo::summarize_batch;
pub use undo::undo_mode_conflict;
pub use undo::validate_undo_list_preview_modes;
pub use verify::ActionAudience;
pub use verify::ActionTemplate;
pub use verify::MachineContractCoverage;
pub use verify::MachineContractInput;
pub use verify::PlainGitVerifyProbe;
pub use verify::RepositoryContextInfo;
pub use verify::RepositoryPresentation;
pub use verify::RepositorySetupActionKind;
pub use verify::RepositorySetupGuidance;
pub use verify::RepositoryVerificationState;
pub use verify::VerificationCheck;
pub use verify::VerifyOptions;
pub use verify::VerifyProfile;
pub use verify::VerifyReport;
pub use verify::build_plain_git_verification_probe;
pub use verify::build_plain_git_verification_probe_with_machine_contract;
pub use verify::build_repository_verification_state;
pub use verify::build_repository_verification_state_with_machine_contract;
pub use verify::build_repository_verification_state_with_worktree_status;
pub use verify::build_repository_verification_state_with_worktree_status_and_machine_contract;
pub use verify::dirty_path_count;
pub use verify::repository_mode_label;
pub use verify::repository_presentation;
pub use verify::repository_setup_action_kind;
pub use verify::repository_setup_guidance;
pub use verify::verify;
pub use visibility_plan::visibility_tier_kind;
pub use visibility_plan::visibility_tier_label;
pub use workflow::AUTO_LAND_CONFIDENCE_RECOVERY_ACTION;
pub use workflow::AUTO_LAND_CONFIDENCE_THRESHOLD;
pub use workflow::AutoLandPolicyInput;
pub use workflow::ReadyDecision;
pub use workflow::ReadyDecisionInput;
pub use workflow::auto_land_confidence_recovery_action;
pub use workflow::auto_land_policy_blockers;
pub use workflow::classify_ready_decision;
pub use workflow::has_integration_target;
pub use workflow::integrated_land_next_action;
pub use workflow::integration_blockers;
pub use workflow::is_heavy_impact_advisory;
pub use workflow::is_integration_clear;
pub use workflow::is_manual_review_blocker;
pub use workflow::land_blockers_for_preview;
pub use workflow::land_checkpoint_message;
pub use workflow::land_performed_steps;
pub use workflow::land_skipped_steps;
pub use workflow::land_text_step;
pub use workflow::land_warnings_for_preview;
pub use workflow::non_staleness_blockers;
pub use workflow::op_targets_merge_state;
pub use workflow::ready_freshness_summary;
pub use workflow::ready_integration_summary;
pub use workflow::ready_merge_type_label;
pub use workflow::ready_merge_type_summary;
pub use workflow::ready_scoped_next_action;
pub use workflow::ready_status_summary;
pub use workflow::ready_verification_preflight_blocks;
pub use workflow::ready_verification_status_blocks;
pub use workflow::recovery_scope_checkout;
pub use workflow::scope_action_to_repo;
pub use workflow::should_squash_land;
pub use workflow::state_id_matches_display;
pub use workflow::state_id_matches_op_display;
pub use workflow::sync_completed_next_action;
pub use workflow::sync_is_already_current;

Modules

actor
Actor presence reports and completion planning.
agent_fanout
Pure agent fanout planning and plan dry-run report assembly.
agent_ops
Pure agent reservation API helpers (non-fanout verbs).
approval_plan
Pure thread-approval display helpers (no hosted network / repo I/O).
clone_plan
Pure clone and adopt planning.
collapse_plan
Pure collapse/expand planning (single decision type).
completion_plan
Pure shell-completion validation (no clap / script I/O / recovery copy).
context
Execution context shared by future facade operations.
context_plan
Pure context query/mutate planning helpers (no store/repo I/O).
contract
Typed machine-output contracts for embeddable Heddle reports.
daemon_plan
Pure mount-daemon status/stop message assembly (no endpoint I/O).
diff
Embeddable diff facade and report model.
doctor_docs_plan
Pure markdown invocation extraction for heddle doctor docs.
doctor_plan
Pure doctor/doctor display helpers (no repo I/O).
doctor_schemas_plan
Pure schema-doc sample extraction and drift helpers for heddle doctor schemas.
fsck
Repository integrity checks.
gc_plan
Pure GC message assembly and dry-run plan tokens (no store I/O).
git_projection_io_plan
Pure Git projection import/export/sync summary strings (no Git I/O).
harness_json
Pure harness relay JSON helpers (no process/registry I/O).
harness_policy
Pure harness session / segment policy (no FS, registry, or process I/O).
hook_plan
Pure hook install planning (no FS / stdin I/O).
identity_cursor
Current harness identity cursor (provider, model, thought_level, session, parent) written by install hooks and frozen onto each capture.
identity_payload
Parse harness hook stdin into an identity-cursor patch.
index_plan
Pure worktree-index dump planning (no FS load / dump I/O).
init_plan
Pure heddle init planning: principal status, side-effects list, paths.
integration_plan
Pure harness integration planning (no FS / env / current_exe I/O).
log_plan
Pure log/reflog helpers: parse, summarize, short ids, timeline labels.
maintenance_plan
Pure maintenance inspect/refresh fact types + one human renderer each.
marker_plan
Pure marker delete/list planning (no refs/oplog I/O).
merge
Merge orchestration facade (planning + apply).
onboarding
Pure repository-onboarding classification.
oplog_plan
Pure oplog recover planning and message assembly (no FS / oplog I/O).
oss_plan
Git-overlay guide content (machine path).
principal
Capture-identity resolution policy.
prove_plan
Pure heddle prove planning helpers (no hosted network / FS I/O).
provenance_verify
Offline verification of the state authorship and review-signature chain.
purge_plan
Pure purge apply planning (force gate + message assembly).
query
Structured query over the operation log.
rebase_plan
Pure rebase preflight planning (no FS / worktree I/O).
redact_plan
Pure redaction display helpers (no crypto/store I/O).
remote
Remote domain helpers: list/show assembly and pure push/pull orchestration.
resolve
Typed report contract for inspectable conflict resolution.
resolve_plan
Pure resolve planning: conflict marker detection and unresolved path sets.
revert_plan
Pure revert planning: empty-diff gate + message assembly.
review
Local typed review implementation used directly by the CLI.
save
Shared save primitive for capture / commit / checkpoint / ready auto-capture.
semantic_plan
Pure semantic hot-event kind tokens and labels (no store I/O, no CLI deps).
shell_plan
Pure shell-hook snippet selection (no FS / stdout I/O).
source_authority
Typed source-authority decisions shared by behavior and recommendations.
spool_plan
Pure spool CLI display helpers (no hosted network / repo I/O).
status
Status facade and report contract.
thread
Thread list/show domain: collection, auto filter, and Git-ref splitting.
thread_lifecycle
Pure thread drop / promote / refresh planning.
thread_materialize
Pure thread materialization planning.
thread_plan
Pure thread create/start planning.
thread_shaping
Thread capture-split and thread-move repository operations.
timeline_plan
Pure timeline CLI planning: parse/label helpers and target selection.
undo
Undo list / planning domain (inspection + batch selection + apply preflight + human labels).
verify
Repository verification facade.
visibility_plan
Pure visibility tier helpers (no store I/O).
watch_plan
Pure heddle watch planning (no FS / notify / oplog I/O).
workflow
Ready / land workflow domain: pure preflight, policy, and step accounting.

Structs

CollectingWarnings
Warning sink useful for embedders and tests that need to inspect warnings.
NoopProgress
Default progress sink for callers that do not care about progress.
NoopWarnings
Default warning sink for callers that do not care about warnings.
TaskId
Stable progress task identifier.
Warning
Structured warning for embedders and render layers.

Enums

HeddleError
Error type for repository/storage-adjacent operations.
ProgressEvent
Structured progress event emitted by long-running operations.

Traits

ProgressSink
Receives structured progress events.
WarningSink
Receives structured warnings that should not be printed by domain crates.

Functions

install_capture_signal_computer
Install the production signal computer for this process.