pub struct ActorChainEntry {
pub session_id: String,
pub native_actor_key: Option<String>,
pub native_parent_actor_key: Option<String>,
pub thread: String,
pub status: String,
pub provider: Option<String>,
pub model: Option<String>,
pub harness: Option<String>,
}Expand description
One hop in an actor ancestry chain for machine JSON.
Fields
session_id: Stringnative_actor_key: Option<String>native_parent_actor_key: Option<String>thread: Stringstatus: Stringprovider: Option<String>model: Option<String>harness: Option<String>Trait Implementations
Sourceimpl Clone for ActorChainEntry
impl Clone for ActorChainEntry
Sourcefn clone(&self) -> ActorChainEntry
fn clone(&self) -> ActorChainEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActorChainEntry
impl Debug for ActorChainEntry
impl Eq for ActorChainEntry
Sourceimpl From<ActorChainNode> for ActorChainEntry
impl From<ActorChainNode> for ActorChainEntry
Sourcefn from(node: ActorChainNode) -> Self
fn from(node: ActorChainNode) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for ActorChainEntry
impl JsonSchema for ActorChainEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ActorChainEntry
impl PartialEq for ActorChainEntry
Sourceimpl Serialize for ActorChainEntry
impl Serialize for ActorChainEntry
impl StructuralPartialEq for ActorChainEntry