pub struct ActorListReport {
pub output_kind: &'static str,
pub actors: Vec<ActorEntryReport>,
pub active_only: bool,
}Expand description
Machine JSON for heddle agent presence list domain fields (stable field names).
CLI may wrap this with a verification envelope; domain fields here match
the public actor_list contract (output_kind, actors, active_only).
Fields
output_kind: &'static stractors: Vec<ActorEntryReport>active_only: boolTrait Implementations
Sourceimpl Clone for ActorListReport
impl Clone for ActorListReport
Sourcefn clone(&self) -> ActorListReport
fn clone(&self) -> ActorListReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActorListReport
impl Debug for ActorListReport
Sourceimpl JsonSchema for ActorListReport
impl JsonSchema for ActorListReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ActorListReport
impl RefUnwindSafe for ActorListReport
impl Send for ActorListReport
impl Sync for ActorListReport
impl Unpin for ActorListReport
impl UnsafeUnpin for ActorListReport
impl UnwindSafe for ActorListReport