pub struct ActorShowReport {
pub actor: ActorEntryReport,
}Expand description
Machine JSON for a single actor-presence payload.
Domain portion only — CLI supplies output_kind and verification when
rendering machine output.
Fields
actor: ActorEntryReportTrait Implementations
Sourceimpl Clone for ActorShowReport
impl Clone for ActorShowReport
Sourcefn clone(&self) -> ActorShowReport
fn clone(&self) -> ActorShowReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActorShowReport
impl Debug for ActorShowReport
Sourceimpl JsonSchema for ActorShowReport
impl JsonSchema for ActorShowReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ActorShowReport
impl RefUnwindSafe for ActorShowReport
impl Send for ActorShowReport
impl Sync for ActorShowReport
impl Unpin for ActorShowReport
impl UnsafeUnpin for ActorShowReport
impl UnwindSafe for ActorShowReport