pub enum CloneThreadSelectError {
RequestedNotAdvertised {
requested: String,
},
NoAdvertisedThreads,
}Expand description
Why clone could not choose a thread to check out.
Variants
RequestedNotAdvertised
--thread named a ref the remote did not advertise.
NoAdvertisedThreads
Remote advertised no usable thread names.