pub fn classify_opencode_plugin_path_mode(
contents: &str,
) -> Option<PathModeKind>Expand description
Probe OpenCode plugin script text for relative vs absolute Bun spawn.
pub fn classify_opencode_plugin_path_mode(
contents: &str,
) -> Option<PathModeKind>Probe OpenCode plugin script text for relative vs absolute Bun spawn.