pub fn parse_hosted_pull_result(
remote_thread: &str,
local_thread: Option<&str>,
fields: &HostedPullResultFields,
) -> HostedPullResultExpand description
Parse hosted pull fields into final state or PullFailure.
pub fn parse_hosted_pull_result(
remote_thread: &str,
local_thread: Option<&str>,
fields: &HostedPullResultFields,
) -> HostedPullResultParse hosted pull fields into final state or PullFailure.