pull_will_materialize

Function pull_will_materialize 

pub fn pull_will_materialize(
    local_thread: Option<&str>,
    remote_thread: &str,
    head: &Head,
) -> bool
Whether a pull would materialize into the current checkout.

Destination track is local_thread when set, otherwise remote_thread. Attached HEAD materializes only when that track equals the attached thread. Detached HEAD materializes only when there is no --local-thread override.