pub struct GitRemoteConfigured {
pub name: String,
pub url: String,
}Expand description
Git remote name/url pair for machine JSON (git_remote_configured).
Fields
name: Stringurl: StringTrait Implementations
Sourceimpl Clone for GitRemoteConfigured
impl Clone for GitRemoteConfigured
Sourcefn clone(&self) -> GitRemoteConfigured
fn clone(&self) -> GitRemoteConfigured
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GitRemoteConfigured
impl Debug for GitRemoteConfigured
impl Eq for GitRemoteConfigured
Sourceimpl JsonSchema for GitRemoteConfigured
impl JsonSchema for GitRemoteConfigured
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GitRemoteConfigured
impl PartialEq for GitRemoteConfigured
Sourceimpl Serialize for GitRemoteConfigured
impl Serialize for GitRemoteConfigured
impl StructuralPartialEq for GitRemoteConfigured