pub struct GitUpstreamConfigured {
pub branch: String,
pub remote: String,
}Expand description
Upstream branch binding for machine JSON (git_upstream_configured).
Fields
branch: Stringremote: StringTrait Implementations
Sourceimpl Clone for GitUpstreamConfigured
impl Clone for GitUpstreamConfigured
Sourcefn clone(&self) -> GitUpstreamConfigured
fn clone(&self) -> GitUpstreamConfigured
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GitUpstreamConfigured
impl Debug for GitUpstreamConfigured
impl Eq for GitUpstreamConfigured
Sourceimpl JsonSchema for GitUpstreamConfigured
impl JsonSchema for GitUpstreamConfigured
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GitUpstreamConfigured
impl PartialEq for GitUpstreamConfigured
Sourceimpl Serialize for GitUpstreamConfigured
impl Serialize for GitUpstreamConfigured
impl StructuralPartialEq for GitUpstreamConfigured