pub struct PullOutcome {Show 22 fields
pub output_kind: &'static str,
pub action: &'static str,
pub status: &'static str,
pub success: bool,
pub pulled: bool,
pub changed: bool,
pub transport: &'static str,
pub remote: String,
pub branch: Option<String>,
pub old_git_head: Option<String>,
pub new_git_head: Option<String>,
pub old_state: Option<String>,
pub new_state: Option<String>,
pub states_created: Option<usize>,
pub commits_seen: Option<usize>,
pub commits_seen_scope: Option<&'static str>,
pub materialized_checkout: Option<bool>,
pub changed_path_count: Option<usize>,
pub changed_paths: Option<Vec<String>>,
pub thread: Option<String>,
pub state: Option<String>,
pub objects: Option<usize>,
}Expand description
Machine JSON body for a successful pull.
Field names match the CLI heddle pull --output json contract.
Fields
output_kind: &'static straction: &'static strstatus: &'static strsuccess: boolpulled: boolchanged: booltransport: &'static strremote: Stringbranch: Option<String>old_git_head: Option<String>new_git_head: Option<String>old_state: Option<String>new_state: Option<String>states_created: Option<usize>commits_seen: Option<usize>commits_seen_scope: Option<&'static str>materialized_checkout: Option<bool>changed_path_count: Option<usize>changed_paths: Option<Vec<String>>thread: Option<String>state: Option<String>objects: Option<usize>Trait Implementations
Sourceimpl Clone for PullOutcome
impl Clone for PullOutcome
Sourcefn clone(&self) -> PullOutcome
fn clone(&self) -> PullOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PullOutcome
impl Debug for PullOutcome
impl Eq for PullOutcome
Sourceimpl JsonSchema for PullOutcome
impl JsonSchema for PullOutcome
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PullOutcome
impl PartialEq for PullOutcome
Sourceimpl Serialize for PullOutcome
impl Serialize for PullOutcome
impl StructuralPartialEq for PullOutcome