pub struct PushOutcome {Show 22 fields
pub output_kind: &'static str,
pub action: &'static str,
pub status: &'static str,
pub success: bool,
pub pushed: bool,
pub changed: bool,
pub transport: &'static str,
pub remote: Option<String>,
pub push_scope: Option<&'static str>,
pub ref_scope: Option<&'static str>,
pub git_notes_ref: Option<&'static str>,
pub refs_written: Option<Vec<String>>,
pub git_notes_visibility_warning: Option<&'static str>,
pub git_tracking_remote: Option<String>,
pub git_remote_configured: Option<GitRemoteConfigured>,
pub git_upstream_configured: Option<GitUpstreamConfigured>,
pub tags_included: Option<bool>,
pub force: Option<bool>,
pub force_discard_warning: Option<&'static str>,
pub thread: Option<String>,
pub state: Option<String>,
pub objects: Option<usize>,
}Expand description
Machine JSON body for a successful (or partial) push.
Field names match the CLI heddle push --output json contract. CLI may
flatten this and attach verification-derived next_action* fields.
Fields
output_kind: &'static straction: &'static strstatus: &'static strsuccess: boolpushed: boolchanged: booltransport: &'static strremote: Option<String>push_scope: Option<&'static str>ref_scope: Option<&'static str>git_notes_ref: Option<&'static str>refs_written: Option<Vec<String>>git_notes_visibility_warning: Option<&'static str>git_tracking_remote: Option<String>git_remote_configured: Option<GitRemoteConfigured>git_upstream_configured: Option<GitUpstreamConfigured>force: Option<bool>force_discard_warning: Option<&'static str>thread: Option<String>state: Option<String>objects: Option<usize>Trait Implementations
Sourceimpl Clone for PushOutcome
impl Clone for PushOutcome
Sourcefn clone(&self) -> PushOutcome
fn clone(&self) -> PushOutcome
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PushOutcome
impl Debug for PushOutcome
impl Eq for PushOutcome
Sourceimpl JsonSchema for PushOutcome
impl JsonSchema for PushOutcome
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PushOutcome
impl PartialEq for PushOutcome
Sourceimpl Serialize for PushOutcome
impl Serialize for PushOutcome
impl StructuralPartialEq for PushOutcome