pub struct AgentReport {
pub provider: String,
pub model: String,
pub session_id: Option<String>,
pub segment_id: Option<String>,
pub policy_id: Option<String>,
}Fields
provider: Stringmodel: Stringsession_id: Option<String>segment_id: Option<String>policy_id: Option<String>Trait Implementations
Sourceimpl Clone for AgentReport
impl Clone for AgentReport
Sourcefn clone(&self) -> AgentReport
fn clone(&self) -> AgentReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentReport
impl Debug for AgentReport
Sourceimpl From<&Agent> for AgentReport
impl From<&Agent> for AgentReport
Sourceimpl JsonSchema for AgentReport
impl JsonSchema for AgentReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentReport
impl RefUnwindSafe for AgentReport
impl Send for AgentReport
impl Sync for AgentReport
impl Unpin for AgentReport
impl UnsafeUnpin for AgentReport
impl UnwindSafe for AgentReport