pub struct ConflictRangeReport {
pub start_line: u32,
pub end_line: u32,
}Fields
start_line: u32end_line: u32Trait Implementations
Sourceimpl Clone for ConflictRangeReport
impl Clone for ConflictRangeReport
Sourcefn clone(&self) -> ConflictRangeReport
fn clone(&self) -> ConflictRangeReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ConflictRangeReport
Sourceimpl Debug for ConflictRangeReport
impl Debug for ConflictRangeReport
Sourceimpl From<ConflictRange> for ConflictRangeReport
impl From<ConflictRange> for ConflictRangeReport
Sourcefn from(range: ConflictRange) -> Self
fn from(range: ConflictRange) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for ConflictRangeReport
impl JsonSchema for ConflictRangeReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConflictRangeReport
impl RefUnwindSafe for ConflictRangeReport
impl Send for ConflictRangeReport
impl Sync for ConflictRangeReport
impl Unpin for ConflictRangeReport
impl UnsafeUnpin for ConflictRangeReport
impl UnwindSafe for ConflictRangeReport