pub struct ConflictSideReport {
pub source_state: String,
pub blob_id: Option<String>,
pub range: ConflictRangeReport,
pub hunk_hash: String,
}Fields
source_state: Stringblob_id: Option<String>range: ConflictRangeReporthunk_hash: StringTrait Implementations
Sourceimpl Clone for ConflictSideReport
impl Clone for ConflictSideReport
Sourcefn clone(&self) -> ConflictSideReport
fn clone(&self) -> ConflictSideReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConflictSideReport
impl Debug for ConflictSideReport
Sourceimpl From<&ConflictSide> for ConflictSideReport
impl From<&ConflictSide> for ConflictSideReport
Sourcefn from(side: &ConflictSide) -> Self
fn from(side: &ConflictSide) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for ConflictSideReport
impl JsonSchema for ConflictSideReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ConflictSideReport
impl RefUnwindSafe for ConflictSideReport
impl Send for ConflictSideReport
impl Sync for ConflictSideReport
impl Unpin for ConflictSideReport
impl UnsafeUnpin for ConflictSideReport
impl UnwindSafe for ConflictSideReport