pub struct PrincipalReport {
pub name: String,
pub email: String,
}Fields
name: Stringemail: StringTrait Implementations
Sourceimpl Clone for PrincipalReport
impl Clone for PrincipalReport
Sourcefn clone(&self) -> PrincipalReport
fn clone(&self) -> PrincipalReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrincipalReport
impl Debug for PrincipalReport
Sourceimpl From<&Principal> for PrincipalReport
impl From<&Principal> for PrincipalReport
Sourceimpl JsonSchema for PrincipalReport
impl JsonSchema for PrincipalReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PrincipalReport
impl RefUnwindSafe for PrincipalReport
impl Send for PrincipalReport
impl Sync for PrincipalReport
impl Unpin for PrincipalReport
impl UnsafeUnpin for PrincipalReport
impl UnwindSafe for PrincipalReport