pub struct ResolverAttributionReport {
pub kind: ResolverKindReport,
pub principal: PrincipalReport,
pub agent: Option<AgentReport>,
}Fields
kind: ResolverKindReportprincipal: PrincipalReportagent: Option<AgentReport>Trait Implementations
Sourceimpl Clone for ResolverAttributionReport
impl Clone for ResolverAttributionReport
Sourcefn clone(&self) -> ResolverAttributionReport
fn clone(&self) -> ResolverAttributionReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolverAttributionReport
impl Debug for ResolverAttributionReport
Sourceimpl From<&Attribution> for ResolverAttributionReport
impl From<&Attribution> for ResolverAttributionReport
Sourcefn from(attribution: &Attribution) -> Self
fn from(attribution: &Attribution) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for ResolverAttributionReport
impl JsonSchema for ResolverAttributionReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResolverAttributionReport
impl RefUnwindSafe for ResolverAttributionReport
impl Send for ResolverAttributionReport
impl Sync for ResolverAttributionReport
impl Unpin for ResolverAttributionReport
impl UnsafeUnpin for ResolverAttributionReport
impl UnwindSafe for ResolverAttributionReport