pub struct CaptureAgentReport {
pub provider: String,
pub model: String,
pub session_id: Option<String>,
pub segment_id: Option<String>,
pub policy_id: Option<String>,
pub thought_level: Option<String>,
pub parent: Option<String>,
}Fields
provider: Stringmodel: Stringsession_id: Option<String>segment_id: Option<String>policy_id: Option<String>thought_level: Option<String>parent: Option<String>Trait Implementations
Sourceimpl Clone for CaptureAgentReport
impl Clone for CaptureAgentReport
Sourcefn clone(&self) -> CaptureAgentReport
fn clone(&self) -> CaptureAgentReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CaptureAgentReport
impl Debug for CaptureAgentReport
impl Eq for CaptureAgentReport
Sourceimpl JsonSchema for CaptureAgentReport
impl JsonSchema for CaptureAgentReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CaptureAgentReport
impl PartialEq for CaptureAgentReport
Sourceimpl Serialize for CaptureAgentReport
impl Serialize for CaptureAgentReport
impl StructuralPartialEq for CaptureAgentReport