pub struct CapturePrincipalReport {
pub name: String,
pub email: String,
}Fields
name: Stringemail: StringTrait Implementations
Sourceimpl Clone for CapturePrincipalReport
impl Clone for CapturePrincipalReport
Sourcefn clone(&self) -> CapturePrincipalReport
fn clone(&self) -> CapturePrincipalReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CapturePrincipalReport
impl Debug for CapturePrincipalReport
impl Eq for CapturePrincipalReport
Sourceimpl JsonSchema for CapturePrincipalReport
impl JsonSchema for CapturePrincipalReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CapturePrincipalReport
impl PartialEq for CapturePrincipalReport
Sourceimpl Serialize for CapturePrincipalReport
impl Serialize for CapturePrincipalReport
impl StructuralPartialEq for CapturePrincipalReport