pub struct SaveReport {Show 25 fields
pub verb: SaveVerb,
pub state_id: StateId,
pub content_hash: ContentHash,
pub intent: Option<String>,
pub confidence: Option<f32>,
pub signed: bool,
pub git_commit: Option<String>,
pub git_previous_commit: Option<String>,
pub summary: String,
pub principal: Principal,
pub agent: Option<Agent>,
pub promotion_suggested: bool,
pub heavy_impact_paths: Vec<String>,
pub captured_path_count: usize,
pub verification: RepositoryVerificationState,
pub created_new_state: bool,
pub git_checkpoint: Option<GitCheckpointRecord>,
pub snapshot_profile: SnapshotProfile,
pub state_create_ms: u128,
pub captured_path_count_ms: u128,
pub post_verification_ms: u128,
pub thread_metadata_ms: u128,
pub previous_state_ms: u128,
pub previous_state_profile: WorktreeStateLookupProfile,
pub signature_lookup_ms: u128,
}Expand description
Result of a successful save.
Fields
verb: SaveVerbstate_id: StateIdcontent_hash: ContentHashintent: Option<String>confidence: Option<f32>signed: boolgit_commit: Option<String>git_previous_commit: Option<String>summary: Stringprincipal: Principalagent: Option<Agent>promotion_suggested: boolheavy_impact_paths: Vec<String>captured_path_count: usizeNumber of paths changed by this save relative to the state that was current when the operation began.
verification: RepositoryVerificationStatecreated_new_state: boolgit_checkpoint: Option<GitCheckpointRecord>snapshot_profile: SnapshotProfilestate_create_ms: u128captured_path_count_ms: u128post_verification_ms: u128thread_metadata_ms: u128previous_state_ms: u128previous_state_profile: WorktreeStateLookupProfilesignature_lookup_ms: u128Trait Implementations
Sourceimpl Clone for SaveReport
impl Clone for SaveReport
Sourcefn clone(&self) -> SaveReport
fn clone(&self) -> SaveReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for SaveReport
impl RefUnwindSafe for SaveReport
impl Send for SaveReport
impl Sync for SaveReport
impl Unpin for SaveReport
impl UnsafeUnpin for SaveReport
impl UnwindSafe for SaveReport