pub struct GitImportGuidanceReport {
pub current_branch: String,
pub missing_branch_count: usize,
pub missing_branches: Vec<String>,
pub recommended_command: String,
}Fields
current_branch: Stringmissing_branch_count: usizemissing_branches: Vec<String>recommended_command: StringTrait Implementations
Sourceimpl Clone for GitImportGuidanceReport
impl Clone for GitImportGuidanceReport
Sourcefn clone(&self) -> GitImportGuidanceReport
fn clone(&self) -> GitImportGuidanceReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GitImportGuidanceReport
impl Debug for GitImportGuidanceReport
Sourceimpl From<GitImportGuidance> for GitImportGuidanceReport
impl From<GitImportGuidance> for GitImportGuidanceReport
Sourcefn from(hint: GitImportGuidance) -> Self
fn from(hint: GitImportGuidance) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for GitImportGuidanceReport
impl JsonSchema for GitImportGuidanceReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GitImportGuidanceReport
impl RefUnwindSafe for GitImportGuidanceReport
impl Send for GitImportGuidanceReport
impl Sync for GitImportGuidanceReport
impl Unpin for GitImportGuidanceReport
impl UnsafeUnpin for GitImportGuidanceReport
impl UnwindSafe for GitImportGuidanceReport