pub struct GitIndexPlan {
pub commit_mode: &'static str,
pub has_staged_changes: bool,
pub staged_paths: Vec<String>,
pub unstaged_paths: Vec<String>,
pub untracked_paths: Vec<String>,
pub will_commit: Vec<String>,
pub preserved_after_commit: Vec<String>,
}Fields
commit_mode: &'static strhas_staged_changes: boolstaged_paths: Vec<String>unstaged_paths: Vec<String>untracked_paths: Vec<String>will_commit: Vec<String>preserved_after_commit: Vec<String>Trait Implementations
Sourceimpl Clone for GitIndexPlan
impl Clone for GitIndexPlan
Sourcefn clone(&self) -> GitIndexPlan
fn clone(&self) -> GitIndexPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GitIndexPlan
impl Debug for GitIndexPlan
Sourceimpl JsonSchema for GitIndexPlan
impl JsonSchema for GitIndexPlan
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GitIndexPlan
impl RefUnwindSafe for GitIndexPlan
impl Send for GitIndexPlan
impl Sync for GitIndexPlan
impl Unpin for GitIndexPlan
impl UnsafeUnpin for GitIndexPlan
impl UnwindSafe for GitIndexPlan