pub struct NativeRemoteStatus {
pub name: String,
pub head: String,
pub relation: &'static str,
}Fields
name: Stringhead: Stringrelation: &'static strTrait Implementations
Sourceimpl Clone for NativeRemoteStatus
impl Clone for NativeRemoteStatus
Sourceimpl Debug for NativeRemoteStatus
impl Debug for NativeRemoteStatus
Sourceimpl JsonSchema for NativeRemoteStatus
impl JsonSchema for NativeRemoteStatus
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for NativeRemoteStatus
impl RefUnwindSafe for NativeRemoteStatus
impl Send for NativeRemoteStatus
impl Sync for NativeRemoteStatus
impl Unpin for NativeRemoteStatus
impl UnsafeUnpin for NativeRemoteStatus
impl UnwindSafe for NativeRemoteStatus