pub struct SubmoduleInfo {
pub path: String,
pub commit: String,
}Fields
path: Stringcommit: StringTrait Implementations
Sourceimpl Clone for SubmoduleInfo
impl Clone for SubmoduleInfo
Sourcefn clone(&self) -> SubmoduleInfo
fn clone(&self) -> SubmoduleInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SubmoduleInfo
impl Debug for SubmoduleInfo
impl Eq for SubmoduleInfo
Sourceimpl JsonSchema for SubmoduleInfo
impl JsonSchema for SubmoduleInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SubmoduleInfo
impl PartialEq for SubmoduleInfo
Sourceimpl Serialize for SubmoduleInfo
impl Serialize for SubmoduleInfo
impl StructuralPartialEq for SubmoduleInfo