pub fn list_threads(
repo: &Repository,
options: ThreadListOptions,
) -> Result<ThreadListReport>Expand description
Collect, filter, and split thread list domain for an opened repository.
pub fn list_threads(
repo: &Repository,
options: ThreadListOptions,
) -> Result<ThreadListReport>Collect, filter, and split thread list domain for an opened repository.