pub fn split_available_git_refs(
summaries: &mut Vec<ThreadListEntry>,
) -> Vec<AvailableGitRef>Expand description
Move available Git-only branch tips out of the main thread list.
pub fn split_available_git_refs(
summaries: &mut Vec<ThreadListEntry>,
) -> Vec<AvailableGitRef>Move available Git-only branch tips out of the main thread list.