pub fn thread_is_available_git_ref(entry: &ThreadListEntry) -> boolExpand description
True when the entry is a Git branch tip without a Heddle tip.
pub fn thread_is_available_git_ref(entry: &ThreadListEntry) -> boolTrue when the entry is a Git branch tip without a Heddle tip.