pub fn thread_is_imported_git_ref(entry: &ThreadListEntry) -> boolExpand description
True when the entry is an imported Git branch already mapped into Heddle.
pub fn thread_is_imported_git_ref(entry: &ThreadListEntry) -> boolTrue when the entry is an imported Git branch already mapped into Heddle.