pub struct AvailableGitRef {
pub name: String,
pub git_commit: String,
pub recommended_action: String,
pub recommended_action_template: Option<ActionTemplate>,
}Expand description
Git-only branch tip that is not yet a Heddle thread tip.
Fields
name: Stringgit_commit: Stringrecommended_action: Stringrecommended_action_template: Option<ActionTemplate>Trait Implementations
Sourceimpl Clone for AvailableGitRef
impl Clone for AvailableGitRef
Sourcefn clone(&self) -> AvailableGitRef
fn clone(&self) -> AvailableGitRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AvailableGitRef
impl Debug for AvailableGitRef
Sourceimpl JsonSchema for AvailableGitRef
impl JsonSchema for AvailableGitRef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AvailableGitRef
impl RefUnwindSafe for AvailableGitRef
impl Send for AvailableGitRef
impl Sync for AvailableGitRef
impl Unpin for AvailableGitRef
impl UnsafeUnpin for AvailableGitRef
impl UnwindSafe for AvailableGitRef