pub struct ThreadTaskSummary {
pub task_id: String,
pub title: String,
pub status: String,
pub target_thread: String,
pub updated_at: String,
pub completed_at: Option<String>,
pub coordination_discussion_id: Option<String>,
}Expand description
Assigned agent task nested on a thread list entry.
Fields
task_id: Stringtitle: Stringstatus: Stringtarget_thread: Stringupdated_at: Stringcompleted_at: Option<String>coordination_discussion_id: Option<String>Trait Implementations
Sourceimpl Clone for ThreadTaskSummary
impl Clone for ThreadTaskSummary
Sourcefn clone(&self) -> ThreadTaskSummary
fn clone(&self) -> ThreadTaskSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThreadTaskSummary
impl Debug for ThreadTaskSummary
impl Eq for ThreadTaskSummary
Sourceimpl From<&AgentTaskRecord> for ThreadTaskSummary
impl From<&AgentTaskRecord> for ThreadTaskSummary
Sourcefn from(task: &AgentTaskRecord) -> Self
fn from(task: &AgentTaskRecord) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for ThreadTaskSummary
impl JsonSchema for ThreadTaskSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ThreadTaskSummary
impl PartialEq for ThreadTaskSummary
Sourceimpl Serialize for ThreadTaskSummary
impl Serialize for ThreadTaskSummary
impl StructuralPartialEq for ThreadTaskSummary