pub struct CheckoutPathPlan {
pub path: PathBuf,
pub from_explicit_path: bool,
}Expand description
Pure plan for where a new thread checkout should land.
Fields
path: PathBufAbsolute or caller-resolved path the start path should use.
from_explicit_path: boolTrue when the planned path is the caller’s explicit --path.
Virtualized mounts always use the managed default so a user-named
directory is never shadowed by a kernel mount; this is false even
if the caller passed --path.