classify_explicit_path_placement

Function classify_explicit_path_placement 

pub fn classify_explicit_path_placement(
    requested: &Path,
    repo_root: &Path,
    heddle_dir: &Path,
) -> ExplicitPathPlacement
Classify an explicit start path relative to repo root / heddle dir.

requested, repo_root, and heddle_dir must be absolute normalized paths. Equality and prefix checks are lexical on those normalized forms.