pub fn explicit_path_allowed_for_git_overlay(
placement: ExplicitPathPlacement,
) -> boolExpand description
Whether an explicit path placement is allowed for a git-overlay repo.
pub fn explicit_path_allowed_for_git_overlay(
placement: ExplicitPathPlacement,
) -> boolWhether an explicit path placement is allowed for a git-overlay repo.