pub struct ThreadMoveOutput {
pub from_thread: String,
pub to_thread: String,
pub moved_paths: Vec<String>,
pub source_state_id: Option<String>,
pub target_state_id: String,
pub message: String,
}Fields
from_thread: Stringto_thread: Stringmoved_paths: Vec<String>source_state_id: Option<String>target_state_id: Stringmessage: StringTrait Implementations
Sourceimpl Clone for ThreadMoveOutput
impl Clone for ThreadMoveOutput
Sourcefn clone(&self) -> ThreadMoveOutput
fn clone(&self) -> ThreadMoveOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ThreadMoveOutput
impl Debug for ThreadMoveOutput
Sourceimpl JsonSchema for ThreadMoveOutput
impl JsonSchema for ThreadMoveOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadMoveOutput
impl RefUnwindSafe for ThreadMoveOutput
impl Send for ThreadMoveOutput
impl Sync for ThreadMoveOutput
impl Unpin for ThreadMoveOutput
impl UnsafeUnpin for ThreadMoveOutput
impl UnwindSafe for ThreadMoveOutput