pub enum TimelinePlanError {
InvalidToolStatus {
raw: String,
},
InvalidBranchReason {
raw: String,
},
InvalidMaterializeMode {
raw: String,
},
ThreadRequired,
TargetRequired,
ToolCallHarnessRequired,
}Expand description
Failures from pure timeline parse / target planning.
Variants
InvalidToolStatus
--status was not one of the known tool-call statuses.
InvalidBranchReason
--reason was not one of the known branch reasons.
InvalidMaterializeMode
--mode was not one of the known materialize modes.
ThreadRequired
Timeline thread name was empty.
TargetRequired
Zero or more than one of --step / --tool-call / --undo / --redo / --current.
ToolCallHarnessRequired
--tool-call was set without a non-empty --harness.