pub fn plan_undo_apply_steps(batches: &[OpBatch]) -> Vec<UndoApplyStep>Expand description
Undo apply order: each batch in selection order, entries reverse within batch.
pub fn plan_undo_apply_steps(batches: &[OpBatch]) -> Vec<UndoApplyStep>Undo apply order: each batch in selection order, entries reverse within batch.