pub struct UndoBatchSummary {
pub batch_id: u64,
pub timestamp: String,
pub undone: bool,
pub partial: bool,
pub operations: Vec<UndoOperationSummary>,
}Expand description
One oplog batch as surfaced by undo list / preview / completed payloads.
Fields
batch_id: u64timestamp: Stringundone: boolpartial: booloperations: Vec<UndoOperationSummary>Trait Implementations
Sourceimpl Clone for UndoBatchSummary
impl Clone for UndoBatchSummary
Sourcefn clone(&self) -> UndoBatchSummary
fn clone(&self) -> UndoBatchSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UndoBatchSummary
impl Debug for UndoBatchSummary
impl Eq for UndoBatchSummary
Sourceimpl JsonSchema for UndoBatchSummary
impl JsonSchema for UndoBatchSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for UndoBatchSummary
impl PartialEq for UndoBatchSummary
Sourceimpl Serialize for UndoBatchSummary
impl Serialize for UndoBatchSummary
impl StructuralPartialEq for UndoBatchSummary