pub struct UndoOperationSummary {
pub id: u64,
pub description: String,
pub timestamp: String,
pub undone: bool,
}Expand description
One operation inside an undo batch summary.
Fields
id: u64description: Stringtimestamp: Stringundone: boolTrait Implementations
Sourceimpl Clone for UndoOperationSummary
impl Clone for UndoOperationSummary
Sourcefn clone(&self) -> UndoOperationSummary
fn clone(&self) -> UndoOperationSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UndoOperationSummary
impl Debug for UndoOperationSummary
impl Eq for UndoOperationSummary
Sourceimpl JsonSchema for UndoOperationSummary
impl JsonSchema for UndoOperationSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for UndoOperationSummary
impl PartialEq for UndoOperationSummary
Sourceimpl Serialize for UndoOperationSummary
impl Serialize for UndoOperationSummary
impl StructuralPartialEq for UndoOperationSummary